@@ -74,23 +74,23 @@ class Genbank:
 
     @property
     def genome_length(self) -> int:
-        """Genome sequence length"""
+        """Range genome sequence length"""
         return len(self.genome_seq)
 
     @property
     def full_genome_seq(self) -> str:
-        """Genome sequence (join all contig sequences)"""
+        """Full genome sequence"""
         return "".join(str(r.seq) for r in self.records)
 
     @property
     def genome_seq(self) -> str:
-        """Genome sequence (join all contig sequences)"""
+        """Range genome sequence"""
         seq = "".join(str(r.seq) for r in self.records)
         return seq[self.min_range - 1 : self.max_range]
 
     @lru_cache(maxsize=None)
-    def calc_average_gc(self) -> float:
-        """Average GC content"""
+    def calc_genome_gc_content(self) -> float:
+        """Calculate genome GC content"""
         return SeqUtils.GC(self.genome_seq)
 
     def calc_gc_skew(
@@ -109,7 +109,7 @@ class Genbank:
 
         Returns
         -------
-        (pos_list, gc_skew_list) : Tuple[np.ndarray, np.ndarray]
+        gc_skew_result_tuple : Tuple[np.ndarray, np.ndarray]
             Position list & GC skew list
         """
         pos_list, gc_skew_list = [], []
@@ -153,7 +153,7 @@ class Genbank:
 
         Returns
         -------
-        (pos_list, gc_content_list) : Tuple[np.ndarray, np.ndarray]
+        gc_content_result_tuple : Tuple[np.ndarray, np.ndarray]
             Position list & GC content list
         """
         pos_list, gc_content_list = [], []
@@ -180,7 +180,7 @@ class Genbank:
         feature_type: str = "CDS",
         target_strand: Optional[int] = None,
         fix_position: bool = True,
-        partial_range: bool = False,
+        allow_partial: bool = True,
     ) -> List[SeqFeature]:
         """Extract features
 
@@ -193,7 +193,7 @@ class Genbank:
         fix_position : bool, optional
             Fix feature start & end position by specified min_range parameter
             (fixed_start = start - min_range - 1, fixed_end = end - min_range - 1)
-        partial_range : bool, optional
+        allow_partial : bool, optional
             If True, features that are partially included in range are also extracted
 
         Returns
@@ -212,10 +212,16 @@ class Genbank:
                     translation = f.qualifiers.get("translation", [None])[0]
                     if translation is None:
                         continue
-                start = self._to_int(f.location.parts[0].start) + base_len
-                end = self._to_int(f.location.parts[-1].end) + base_len
+                if f.strand == -1:
+                    # Handle rare case (complement & join)
+                    # Found in NC_00913 protein_id=NP_417367.1
+                    start = self._to_int(f.location.parts[-1].start) + base_len
+                    end = self._to_int(f.location.parts[0].end) + base_len
+                else:
+                    start = self._to_int(f.location.parts[0].start) + base_len
+                    end = self._to_int(f.location.parts[-1].end) + base_len
                 # Restrict features in range
-                if partial_range:
+                if allow_partial:
                     if (
                         not min_range <= start <= max_range
                         and not min_range <= end <= max_range
