@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import warnings
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple, Union
 
@@ -12,6 +13,8 @@ from matplotlib.ticker import MaxNLocator
 from pygenomeviz.link import Link
 from pygenomeviz.track import FeatureSubTrack, FeatureTrack, LinkTrack, TickTrack, Track
 
+warnings.filterwarnings("ignore")
+
 
 class GenomeViz:
     """GenomeViz Class"""
@@ -21,9 +24,6 @@ class GenomeViz:
         fig_width: float = 15,
         fig_track_height: float = 1.0,
         align_type: str = "left",
-        feature_size_ratio: float = 0.9,
-        link_size_ratio: float = 0.9,
-        arrow_shaft_ratio: float = 0.5,
         feature_track_ratio: float = 1.0,
         link_track_ratio: float = 1.0,
         tick_track_ratio: float = 1.0,
@@ -41,12 +41,6 @@ class GenomeViz:
             Figure track height
         align_type : str, optional
             Track align type
-        feature_size_ratio : float, optional
-            Feature size ratio to track
-        link_size_ratio : float, optional
-            Link size ratio to track
-        arrow_shaft_ratio : float, optional
-            Feature arrow shaft ratio
         feature_track_ratio : float, optional
             Feature track ratio
         link_track_ratio : float, optional
@@ -58,22 +52,16 @@ class GenomeViz:
         tick_style : Optional[str], optional
             Tick style (`axis`|`bar`)
         plot_size_thr : float, optional
-            Plot size threshold
+            Plot feature size threshold.
+            If `plot_size_thr=0.0005` and `max_track_size=4.0Mb`, feature smaller than
+            `max_track_size * plot_size_thr=2.0Kb` are not plotted.
         tick_labelsize : int, optional
             Tick label size
-
-        Notes
-        -----
-        If `plot_size_thr=0.0005` and `max_track_size=4.0Mb`, features smaller than
-        `max_track_size * plot_size_thr=2.0Kb` are not plotted.
         """
         self.fig_width = fig_width
         self.fig_track_height = fig_track_height
         self.align_type = align_type
         self.track_spines = track_spines
-        self.feature_size_ratio = feature_size_ratio
-        self.link_size_ratio = link_size_ratio
-        self.arrow_shaft_ratio = arrow_shaft_ratio
         self.feature_track_ratio = feature_track_ratio
         self.link_track_ratio = link_track_ratio
         self.tick_track_ratio = tick_track_ratio
@@ -94,18 +82,6 @@ class GenomeViz:
             err_msg = f"Invalid tick type '{self.tick_style}'."
             raise ValueError(err_msg)
 
-        range_check_dict = {
-            "feature_size_ratio": self.feature_size_ratio,
-            "link_size_ratio": self.link_size_ratio,
-            "arrow_shaft_ratio": self.arrow_shaft_ratio,
-        }
-        err_msg = ""
-        for k, v in range_check_dict.items():
-            if not 0 <= v <= 1:
-                err_msg += f"'{k}' must be '0 <= value <= 1' (value={v})\n"
-        if err_msg:
-            raise ValueError(err_msg)
-
     def _get_track_offset(self, track: Track) -> int:
         """Get track offset
 
@@ -175,6 +151,7 @@ class GenomeViz:
         name: str,
         size: int,
         labelsize: int = 20,
+        labelmargin: float = 0.01,
         linewidth: int = 1,
     ) -> FeatureTrack:
         """Add feature track
@@ -187,6 +164,8 @@ class GenomeViz:
             Track size
         labelsize : int, optional
             Track label size
+        labelmargin : flaot, optional
+            Track label margin
         linewidth : int, optional
             Track line width
 
@@ -212,6 +191,7 @@ class GenomeViz:
             name,
             size,
             labelsize,
+            labelmargin,
             linewidth,
             self.track_spines,
             self.feature_track_ratio,
@@ -255,11 +235,12 @@ class GenomeViz:
         track_link2: Tuple[str, int, int],
         normal_color: str = "grey",
         inverted_color: str = "red",
-        alpha: float = 1.0,
-        interpolation_value: Optional[float] = None,
+        alpha: float = 0.8,
+        v: Optional[float] = None,
         vmin: float = 0,
         vmax: float = 100,
         curve: bool = False,
+        size_ratio: float = 0.9,
     ) -> None:
         """Add link data to link track
 
@@ -275,7 +256,7 @@ class GenomeViz:
             Inverted link color
         alpha : float, optional
             Color transparency
-        interpolation_value : Optional[float], optional
+        v : Optional[float], optional
             Value for color interpolation
         vmin : float, optional
             Min value for color interpolation
@@ -283,6 +264,8 @@ class GenomeViz:
             Max value for color interpolation
         curve : bool, optional
             If True, bezier curve link is plotted
+        size_ratio : float, optional
+            Link size ratio to track
         """
         link_track = self._get_link_track(track_link1[0], track_link2[0])
         tracks = [t.name for t in self.get_tracks()]
@@ -303,10 +286,11 @@ class GenomeViz:
                 normal_color,
                 inverted_color,
                 alpha,
-                interpolation_value,
+                v,
                 vmin,
                 vmax,
                 curve,
+                size_ratio,
             )
         )
 
@@ -371,7 +355,7 @@ class GenomeViz:
             raise ValueError(err_msg)
         return max([track.size for track in self.get_tracks()])
 
-    def plotfig(self, dpi: int = 300) -> Figure:
+    def plotfig(self, dpi: int = 100) -> Figure:
         """Plot figure
 
         Parameters
@@ -400,7 +384,12 @@ class GenomeViz:
 
         track_num = len(self.get_tracks(subtrack=True))
         figsize = (self.fig_width, self.fig_track_height * track_num)
-        figure: Figure = plt.figure(figsize=figsize, facecolor="white", dpi=dpi)
+        figure: Figure = plt.figure(
+            figsize=figsize,
+            facecolor="white",
+            dpi=dpi,
+            tight_layout=False if track_num < 3 else True,
+        )
 
         track_ratios = [t.ratio for t in self.get_tracks(subtrack=True)]
         spec = gridspec.GridSpec(
@@ -422,7 +411,8 @@ class GenomeViz:
             if isinstance(track, FeatureTrack):
                 # Plot track label
                 if track.labelsize != 0:
-                    ax.text(-self.max_track_size * 0.01, 0, **track.label_params)
+                    margin = -self.max_track_size * track.labelmargin
+                    ax.text(margin, 0, **track.label_params)
                 # Plot track scale line
                 xmin, xmax = track_offset, track.size + track_offset
                 ax.hlines(0, xmin, xmax, "black", linewidth=track.linewidth)
@@ -432,28 +422,20 @@ class GenomeViz:
                     if feature.length < self.max_track_size * self.plot_size_thr:
                         continue
                     # Plot feature object
-                    obj_params = feature.obj_params(
-                        self.max_track_size,
-                        ylim,
-                        self.feature_size_ratio,
-                        self.arrow_shaft_ratio,
-                    )
+                    obj_params = feature.obj_params(self.max_track_size, ylim)
                     ax.arrow(**obj_params)
                     # Plot feature text
                     if feature.labelsize != 0:
-                        ax.text(**feature.text_params(ylim, self.feature_size_ratio))
+                        ax.text(**feature.text_params(ylim))
 
-            if isinstance(track, FeatureSubTrack):
+            elif isinstance(track, FeatureSubTrack):
                 # No specific plans to implementation at this time
                 pass
 
             elif isinstance(track, LinkTrack):
                 for link in track.links:
                     link = link.add_offset(self._track_name2offset)
-                    link_ymin = ylim[0] * self.link_size_ratio
-                    link_ymax = ylim[1] * self.link_size_ratio
-                    path = link.path(link_ymin, link_ymax)
-                    p = patches.PathPatch(path, fc=link.color, linewidth=0)
+                    p = patches.PathPatch(link.path(ylim), fc=link.color, linewidth=0)
                     ax.add_patch(p)
 
             elif isinstance(track, TickTrack):
@@ -468,12 +450,15 @@ class GenomeViz:
                     ax.vlines(track.xmax, ymin, ymax, **common_opts)
                     ax.text(**track.scalebar_text_params)
 
+            else:
+                raise NotImplementedError()
+
         return figure
 
     def savefig(
         self,
         savefile: Union[str, Path],
-        dpi: int = 300,
+        dpi: int = 100,
         pad_inches: float = 0.5,
     ) -> None:
         """Save figure to file
@@ -530,12 +515,13 @@ class GenomeViz:
         self,
         figure: Figure,
         bar_colors: List[str] = ["grey", "red"],
-        alpha: float = 1.0,
+        alpha: float = 0.8,
         vmin: float = 0,
         vmax: float = 100,
-        bar_height: float = 0.3,
+        bar_height: float = 0.2,
         bar_width: float = 0.01,
-        bar_bottom: float = 0.1,
+        bar_left: float = 1.01,
+        bar_bottom: float = 0.05,
         bar_label: str = "",
         bar_labelsize: float = 15,
         tick_labelsize: float = 10,
@@ -560,6 +546,8 @@ class GenomeViz:
             Colorbar height
         bar_width : float, optional
             Colorbar width
+        bar_left : float, optional
+            Colorbar left position
         bar_bottom : float, optional
             Colorbar bottom position
         bar_label : str, optional
@@ -569,15 +557,17 @@ class GenomeViz:
         tick_labelsize : float, optional
             Colorbar tick label size
         """
-        # Adjust subplot layout (Add right margin)
-        right_adjust = 0.90
-        figure.subplots_adjust(right=right_adjust)
-        # Plot colorbars
-        init_left = right_adjust + 0.05
         for cnt, color in enumerate(bar_colors):
-            left = init_left + bar_width * cnt
+            left = bar_left + bar_width * cnt
             cbar_ax = figure.add_axes([left, bar_bottom, bar_width, bar_height])
-            cmap = colors.LinearSegmentedColormap.from_list("cmap", ("white", color))
+
+            def to_nearly_white(color: str, nearly_value: float = 0.1) -> str:
+                """Convert target color to nearly white"""
+                cmap = colors.LinearSegmentedColormap.from_list("m", ("white", color))
+                return colors.to_hex(cmap(nearly_value))
+
+            nearly_white = to_nearly_white(color)
+            cmap = colors.LinearSegmentedColormap.from_list("m", (nearly_white, color))
             norm = colors.Normalize(vmin=vmin, vmax=vmax)
             cb_props = {"orientation": "vertical", "ticks": []}
             cb = ColorbarBase(cbar_ax, cmap=cmap, norm=norm, alpha=alpha, **cb_props)
