@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import Dict, Optional
+from typing import Dict, Optional, Tuple
 
 from matplotlib import colors
 from matplotlib.path import Path
@@ -20,11 +20,12 @@ class Link:
     track_end2: int
     normal_color: str = "grey"
     inverted_color: str = "red"
-    alpha: float = 1.0
-    interpolation_value: Optional[float] = None
+    alpha: float = 0.8
+    v: Optional[float] = None
     vmin: float = 0
     vmax: float = 100
     curve: bool = False
+    size_ratio: float = 0.9
 
     def __post_init__(self):
         if not colors.is_color_like(self.normal_color):
@@ -33,28 +34,31 @@ class Link:
         if not colors.is_color_like(self.inverted_color):
             err_msg = f"'inverted_color={self.inverted_color}' is not color like."
             raise ValueError(err_msg)
-        if self.interpolation_value is not None:
-            if not self.vmin <= self.interpolation_value <= self.vmax:
+        # Check size ratio
+        if not 0 <= self.size_ratio <= 1:
+            err_msg = "'size_ratio' must be '0 <= value <= 1' "
+            err_msg += f"(value={self.size_ratio})"
+            raise ValueError(err_msg)
+        if self.v is not None:
+            if not self.vmin <= self.v <= self.vmax:
                 err_msg = "'Interpolation value must be "
-                err_msg += f"'{self.vmin} <= value <= {self.vmax}' "
-                err_msg += f"(value={self.interpolation_value})"
+                err_msg += f"'{self.vmin} <= value <= {self.vmax}' (value={self.v})"
                 raise ValueError(err_msg)
 
-    def path(self, ymin: float = -1.0, ymax: float = 1.0) -> Path:
+    def path(self, ylim: Tuple[float, float] = (-1.0, 1.0)) -> Path:
         """Link path
 
         Parameters
         ----------
-        ymin : float, optional
-            Min y coordinate
-        ymax : float, optional
-            Max y coordinate
+        ylim: Tuple[flaot, float], optional
+            Min-Max y coordinatess
 
         Returns
         -------
         path : Path
             Link path
         """
+        ymin, ymax = ylim[0] * self.size_ratio, ylim[1] * self.size_ratio
         if self.curve:
             codes = [
                 Path.MOVETO,
@@ -92,20 +96,22 @@ class Link:
 
     @property
     def color(self) -> str:
-        """Get conditional hexcolor code
-
-        Notes
-        -----
-        If `self.interpolation_value` is set, interpolated color is calculated.
-        """
+        """Get conditional hexcolor code"""
         color = self.inverted_color if self.is_inverted else self.normal_color
-        if self.interpolation_value is None:
+        if self.v is None:
             rgba = colors.to_rgba(color, alpha=self.alpha)
             return colors.to_hex(rgba, keep_alpha=True)
         else:
-            cmap = colors.LinearSegmentedColormap.from_list("cmap", ("white", color))
+
+            def to_nearly_white(color: str, nearly_value: float = 0.1) -> str:
+                """Convert target color to nearly white"""
+                cmap = colors.LinearSegmentedColormap.from_list("m", ("white", color))
+                return colors.to_hex(cmap(nearly_value))
+
+            nearly_white = to_nearly_white(color)
+            cmap = colors.LinearSegmentedColormap.from_list("m", (nearly_white, color))
             norm = colors.Normalize(vmin=self.vmin, vmax=self.vmax)
-            norm_value = norm(self.interpolation_value)
+            norm_value = norm(self.v)
             return colors.to_hex(cmap(norm_value, alpha=self.alpha), keep_alpha=True)
 
     @property
