@@ -18,6 +18,7 @@ class Track:
         name: str,
         size: int,
         labelsize: int = 0,
+        labelmargin: float = 0,
         linewidth: int = 0,
         spines: bool = False,
         ratio: float = 1.0,
@@ -31,6 +32,8 @@ class Track:
             Track size
         labelsize : int, optional
             Track label size
+        labelmargin : float, optional
+            Track label margin
         linewidth : int, optional
             Track line width
         spines : bool, optional
@@ -41,6 +44,7 @@ class Track:
         self.name = name
         self.size = size
         self.labelsize = labelsize
+        self.labelmargin = labelmargin
         self.linewidth = linewidth
         self.spines = spines
         self.ratio = ratio
@@ -89,18 +93,14 @@ class Track:
     def ax(self) -> Axes:
         """Track axes
 
+        Can't access ax property before calling GenomeViz class `plotfig` method.
+
         Returns
         -------
         ax : Axes
             Track matplotlib axes object
-
-        Notes
-        -----
-        Can't access ax property before calling GenomeViz class `plotfig` method.
-
-        Pre-defined property of Axes
-        - xlim = (0, gv.max_track_size)
-        - ylim = (-1, 1)
+            - xlim = `(0, gv.max_track_size)`
+            - ylim = `(-1, 1)`
         """
         if self._ax is None:
             err_msg = "Can't access ax property before calling 'plotfig' method."
@@ -115,8 +115,9 @@ class FeatureTrack(Track):
         self,
         name: str,
         size: int,
-        labelsize: int = 30,
-        linewidth: int = 2,
+        labelsize: int = 20,
+        labelmargin: float = 0.01,
+        linewidth: int = 1,
         spines: bool = False,
         ratio: float = 1.0,
     ):
@@ -129,6 +130,8 @@ class FeatureTrack(Track):
             Track size
         labelsize : int, optional
             Track label size
+        labelmargin : float, optional
+            Track label margin
         linewidth : int, optional
             Track line width
         spines : bool, optional
@@ -136,7 +139,7 @@ class FeatureTrack(Track):
         ratio : float, optional
             Track height ratio
         """
-        super().__init__(name, size, labelsize, linewidth, spines, ratio)
+        super().__init__(name, size, labelsize, labelmargin, linewidth, spines, ratio)
         self.features: List[Feature] = []
         self.subtracks: List[FeatureSubTrack] = []
 
@@ -167,10 +170,12 @@ class FeatureTrack(Track):
         facecolor: str = "orange",
         edgecolor: str = "black",
         linewidth: float = 0,
-        labelrotation: int = 30,
+        labelrotation: int = 45,
         labelvpos: str = "strand",
         labelhpos: str = "center",
         labelha: str = "left",
+        arrow_shaft_ratio: float = 0.5,
+        size_ratio: float = 0.9,
     ) -> None:
         """Add feature to track
 
@@ -205,6 +210,10 @@ class FeatureTrack(Track):
             Feature label horizontal position (`left`|`center`|`right`)
         labelha : str, optional
             Feature label horizontal alignment (`left`|`center`|`right`)
+        arrow_shaft_ratio : float, optional
+            Feature arrow shaft ratio
+        size_ratio : float, optional
+            Feature size ratio to track
         """
         self.features.append(
             Feature(
@@ -222,6 +231,8 @@ class FeatureTrack(Track):
                 labelvpos,
                 labelhpos,
                 labelha,
+                arrow_shaft_ratio,
+                size_ratio,
             )
         )
 
@@ -230,16 +241,20 @@ class FeatureTrack(Track):
         gbk: Genbank,
         feature_type: str = "CDS",
         label_type: Optional[str] = None,
+        label_filter: Optional[List[str]] = None,
+        allow_partial: bool = True,
         labelsize: int = 15,
         labelcolor: str = "black",
         plotstyle: str = "bigarrow",
         facecolor: str = "orange",
         edgecolor: str = "black",
         linewidth: float = 0,
-        labelrotation: int = 30,
+        labelrotation: int = 45,
         labelvpos: str = "strand",
         labelhpos: str = "center",
         labelha: str = "left",
+        arrow_shaft_ratio: float = 0.5,
+        size_ratio: float = 0.9,
     ):
         """Add features from genbank record
 
@@ -251,6 +266,11 @@ class FeatureTrack(Track):
             Feature type (e.g. `CDS`,`rRNA`,`tRNA`,etc...)
         label_type : Optional[str], optional
             Label type (e.g. `gene`,`protein_id`,`product`,etc...)
+        label_filter : Optional[List[str]], optional
+            Label filter string list (e.g. `hypothetical`, `uncharacterized`)
+            If label contains target string, make it empty.
+        allow_partial : bool, optional
+            If True, features that are partially included in range are also extracted
         labelsize : int, optional
             Feature label size
         labelcolor : str, optional
@@ -271,8 +291,12 @@ class FeatureTrack(Track):
             Feature label horizontal position (`left`|`center`|`right`)
         labelha : str, optional
             Feature label horizontal alignment (`left`|`center`|`right`)
+        arrow_shaft_ratio : float, optional
+            Feature arrow shaft ratio
+        size_ratio : float, optional
+            Feature size ratio to track
         """
-        target_features = gbk.extract_features(feature_type)
+        target_features = gbk.extract_features(feature_type, None, True, allow_partial)
         for feature in target_features:
             start = int(str(feature.location.start))
             end = int(str(feature.location.end))
@@ -281,6 +305,9 @@ class FeatureTrack(Track):
                 label = ""
             else:
                 label = feature.qualifiers.get(label_type, [""])[0]
+                if label_filter is not None:
+                    for filter_str in label_filter:
+                        label = "" if filter_str in label else label
             self.features.append(
                 Feature(
                     start,
@@ -297,6 +324,8 @@ class FeatureTrack(Track):
                     labelvpos,
                     labelhpos,
                     labelha,
+                    arrow_shaft_ratio,
+                    size_ratio,
                 )
             )
 
@@ -305,7 +334,7 @@ class FeatureSubTrack(Track):
     """FeatureSubTrack Class"""
 
     def __init__(self, name: str, size: int, spines: bool = False, ratio: float = 1.0):
-        super().__init__(name, size, 0, 0, spines, ratio)
+        super().__init__(name, size, 0, 0, 0, spines, ratio)
 
 
 class LinkTrack(Track):
@@ -322,7 +351,7 @@ class LinkTrack(Track):
         ratio : float, optional
             Track height ratio
         """
-        super().__init__(name, 0, 0, 0, spines, ratio)
+        super().__init__(name, 0, 0, 0, 0, spines, ratio)
         self.links: List[Link] = []
 
     def add_link(self, link: Link) -> None:
@@ -361,7 +390,7 @@ class TickTrack(Track):
         tick_style : str, optional
             Tick style (`axis`|`bar`)
         """
-        super().__init__("tick", size, labelsize, 0, spines, ratio)
+        super().__init__("tick", size, labelsize, 0, 0, spines, ratio)
         self.tick_style = tick_style
 
     @property
